/* $Id: dmsconv.h,v 1.6 2007/12/10 09:34:01 cvsroot Exp $ */

/* GenLib2 - General Library 2
 * Copyright (C) 2005 Dirk Stallmann
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */

#ifndef GENLIB2_DMSCONV_INCLUDED
#define GENLIB2_DMSCONV_INCLUDED

#if defined(_WIN32)
	#define COPYSIGN _copysign
#else
	#define COPYSIGN copysign
#endif


// external math-subroutines
#if !defined(_WIN32)
	extern "C"
	{
		double COPYSIGN(double x, double y);
		double fabs(double x);
		double floor(double x);
	}
#endif


namespace GenLib2
{

/// convert DMS into decimal representation
template<class T> inline
T dms2dec(T d, T m, T s)
{
	return T(COPYSIGN(fabs(d) + m / 60. + s / 3600., d));
}


/// convert decimal into DMS representation
template<class T> inline
void dec2dms(T a, T& d, T& m, T& s)
{
	T b = fabs(a);			// absolute value
	d = floor(b);			// degree
	T t = (b - d) * 60.;	// remainder
	m = floor(t);			// minutes
	s = (t - m) * 60;		// seconds
	d = COPYSIGN(d, a);		// copy sign
}

} // namespace GenLib2

#endif /* GENLIB2_DMSCONV_INCLUDED */

