/**********************************************************************/
//
// FILE:    convrot.cpp
//          General conversion of rotation parameters.
//          This program convert different types rotation parameters 
//          of the exterior orientation (EO). Each set of EO consist of
//          the following parameters:
//
//            id             - identifier, the  image name or number
//            t              - (GPS-)time (optional)
//            Xo, Yo, Zo     - 3 perspective centre coordinates (optional)
//            p1, p2, ... p9 - 3 until 9 rotations parameters.
//
//          The EO data is read from in_file, the rotation parameters
//          are converted and written to the out_file.
//          The parameters id, time and perspective centre coordinates
//          are handed as strings and therefore unchanged!
//          The input and output format is:
//
//             id   [t]   [Xo   Yo   Zo]   p1   p2   p3  [... p9]
//
// CREATED: 10 Dec 00  (ds)
// CHANGES: 
// REFS:
//
// (c) 2003 Dirk Stallmann (ds)/ IfP Uni Stuttgart
/**********************************************************************/

#include <stdlib.h>
#include <string>
#include <strstream.h>
#include <fstream>

const char* const program_name = "readheader";
const char* const program_version = "version 0.1 (05/03)";


static void error(const char *s, const char *s2 = "")
{
	cerr << program_name << ": " << s << ' ' << s2 << endl;
	exit(1);
}


int main(int argc, char *argv[])
{
	ifstream is(argv[1]);
	if (!is) error("Cannot open input file:", argv[1]);

	// read header lines
	char c = 0;
	const int maxline = 1024;
	char line[maxline];

	while (1)
		{
		is >> c;

		// look for header lines
		if (c == '#')
			{
			// if we're at a comment, get the line
			// including the leading character!
			is.putback(c);
			is.getline(line, maxline, '\n');
			cout << "header line!" << endl;
			cout << "line: >" << line << "<" << endl;

			istrstream iss(line, maxline);

			// look for keywords
			string key;
			iss >> c >> key;
			if (!iss) error("Reading header line failed.");
			cout << "key: >" << key << "<" << endl;
			cout << endl;
			}
		else
			{
			is.putback(c);
			break;
			}
		}

	cout << "processing the rest" << endl;

	return 0;
}
